aboutsummaryrefslogtreecommitdiffstats
path: root/actionpack/lib/action_view
diff options
context:
space:
mode:
authorJosé Valim <jose.valim@gmail.com>2011-01-19 23:42:10 +0100
committerJosé Valim <jose.valim@gmail.com>2011-01-19 23:42:10 +0100
commit262b2ea8cda20999ddf8c4bf13b7a70453e996d2 (patch)
treee755f0cca04acabd901abe681d1189870570cf0c /actionpack/lib/action_view
parentb247f3944282fb22c68fd4f9248a16fcda63b186 (diff)
downloadrails-262b2ea8cda20999ddf8c4bf13b7a70453e996d2.tar.gz
rails-262b2ea8cda20999ddf8c4bf13b7a70453e996d2.tar.bz2
rails-262b2ea8cda20999ddf8c4bf13b7a70453e996d2.zip
Solve SystemStackError when changing locale inside ActionMailer [#5329 state:resolved]
Diffstat (limited to 'actionpack/lib/action_view')
-rw-r--r--actionpack/lib/action_view/lookup_context.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/actionpack/lib/action_view/lookup_context.rb b/actionpack/lib/action_view/lookup_context.rb
index 1365048724..e434f3b059 100644
--- a/actionpack/lib/action_view/lookup_context.rb
+++ b/actionpack/lib/action_view/lookup_context.rb
@@ -186,11 +186,11 @@ module ActionView
end
# Overload locale= to also set the I18n.locale. If the current I18n.config object responds
# to i18n_config, it means that it's has a copy of the original I18n configuration and it's
# acting as proxy, which we need to skip.
def locale=(value)
if value
- config = I18n.config.respond_to?(:i18n_config) ? I18n.config.i18n_config : I18n.config
+ config = I18n.config.respond_to?(:original_config) ? I18n.config.original_config : I18n.config
config.locale = value
end
@@ -186,11 +186,11 @@ module ActionView
end
# Overload locale= to also set the I18n.locale. If the current I18n.config object responds
- # to i18n_config, it means that it's has a copy of the original I18n configuration and it's
+ # to original_config, it means that it's has a copy of the original I18n configuration and it's
# acting as proxy, which we need to skip.
def locale=(value)